@@ -240,6 +240,9 @@ SERVICE_VERSIONS = {
     "lke": [
         "2023-11-30"
     ],
+    "lkeap": [
+        "2024-05-22"
+    ],
     "mariadb": [
         "2017-03-12"
     ],
@@ -358,6 +361,9 @@ SERVICE_VERSIONS = {
         "2022-09-01",
         "2022-01-06"
     ],
+    "tione": [
+        "2021-11-11"
+    ],
     "tiw": [
         "2019-09-19"
     ],
